# Common Code
Code that both LiveCellAnalysis and smFISH (or others) use and doesn't get major changes goes here.

# Installation (Ubuntu)

    pip install tllab_common

or editable:

    git clone git@github.com:Lenstralab/tllab_common.git
    pip install -e tllab_common/ --user